@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2004-2018  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2004-2019  Ruby-GNOME Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ rg_flags_add_constants(VALUE mod, GType flags_type, const gchar *strip_prefix)
 {
     GFlagsClass *gclass;
     guint i;
-    int prefix_len = strlen(strip_prefix);
+    size_t prefix_len = strlen(strip_prefix);
 
     gclass = G_FLAGS_CLASS(g_type_class_ref(flags_type));
 
@@ -80,11 +80,10 @@ static const rb_data_type_t rg_glib_flags_type = {
     {
         NULL,
         flags_free,
-        NULL,
     },
     NULL,
     NULL,
-    RUBY_TYPED_FREE_IMMEDIATELY,
+    RUBY_TYPED_FREE_IMMEDIATELY | RUBY_TYPED_FROZEN_SHAREABLE,
 };
 
 static flags_holder*
@@ -273,7 +272,7 @@ resolve_flags_value(VALUE klass, GFlagsClass *gclass, VALUE flag_or_flags)
     }
     case RUBY_T_ARRAY:
     {
-        int i, n;
+        long i, n;
         n = RARRAY_LEN(flag_or_flags);
         for (i = 0; i < n; i++) {
             value |= resolve_flags_value(klass,
@@ -370,7 +369,8 @@ flags_compare_get_flags_body(VALUE user_data)
 }
 
 static VALUE
-flags_compare_get_flags_rescue(VALUE user_data)
+flags_compare_get_flags_rescue(VALUE user_data,
+                               G_GNUC_UNUSED VALUE error)
 {
     compare_data *data = (compare_data *)user_data;
 
@@ -466,7 +466,7 @@ rg_operator_flags_lt(VALUE self, VALUE rhs)
 }
 
 static VALUE
-rg_operator_flags_not(VALUE self, G_GNUC_UNUSED VALUE rhs)
+rg_operator_flags_not(VALUE self)
 {
     flags_holder* p = flags_get_holder(self);
     return rbgobj_make_flags((~ p->value) & p->gclass->mask,
@@ -542,7 +542,7 @@ Init_gobject_gflags(void)
     id_or = rb_intern("|");
     id_to_i = rb_intern("to_i");
 
-    RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_FLAGS, "Flags", mGLib);
+    RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_FLAGS, "Flags", rbg_mGLib());
 
     rbg_define_singleton_method(RG_TARGET_NAMESPACE, "gtype", generic_s_gtype, 0);
     rbg_define_method(RG_TARGET_NAMESPACE, "gtype", generic_gtype, 0);
